@@ -67,6 +67,15 @@ pub struct Args {
     #[structopt(skip)]
     pub qnames: Vec<String>,
 
+    #[structopt(skip)]
+    pub nameservers: Vec<String>,
+
+    #[structopt(short = "s", long = "save", help = "save responses to file")]
+    pub save_path: Option<String>,
+
+    #[structopt(short = "r", long = "read", help = "read responses from file")]
+    pub read_path: Option<String>,
+
     #[structopt(verbatim_doc_comment)]
     /// Positional arguments ...
     ///
@@ -125,6 +134,33 @@ impl Args {
         Ok(args)
     }
 
+    pub fn cmd_line(&self) -> String {
+        let pfx = if self.has_save_path() {
+            format!("--save {} ", self.save_path.as_deref().unwrap())
+        } else if self.has_read_path() {
+            format!("--read {} ", self.read_path.as_deref().unwrap())
+        } else {
+            "".to_string()
+        };
+        format!("{}{}", pfx, self.positional.join(" "))
+    }
+
+    pub fn has_save_path(&self) -> bool {
+        if let Some(ref path) = self.save_path {
+            !path.is_empty()
+        } else {
+            false
+        }
+    }
+
+    pub fn has_read_path(&self) -> bool {
+        if let Some(ref path) = self.read_path {
+            !path.is_empty()
+        } else {
+            false
+        }
+    }
+
     pub fn qtype(&self) -> Type {
         self.qtype.unwrap()
     }
@@ -180,7 +216,10 @@ impl Args {
                 "+rust" => format = OutputFormat::Rust,
                 "+norust" => format = OutputFormat::Zone,
                 s if s.starts_with('@') => match IpAddr::from_str(&s[1..]) {
-                    Ok(addr) => nameserver_ip_addr = Some(addr),
+                    Ok(addr) => {
+                        self.nameservers.push(s[1..].to_string());
+                        nameserver_ip_addr = Some(addr)
+                    }
                     Err(_) => {
                         eprintln!("failed to parse nameserver ip address");
                         exit(1);
