@@ -10,6 +10,7 @@ use rsdns::{
 };
 use std::{
     fmt::Write,
+    net::SocketAddr,
     time::{Duration, SystemTime},
 };
 
@@ -27,12 +28,12 @@ struct Sizes {
 }
 
 #[allow(dead_code)]
-pub struct Output<'a, 'b, 'c> {
+pub struct Output<'a, 'b> {
     args: &'a Args,
-    qname: &'b str,
-    msg: &'c [u8],
-    ts: SystemTime,
-    elapsed: Duration,
+    msg: &'b [u8],
+    ns: Option<SocketAddr>,
+    ts: Option<SystemTime>,
+    elapsed: Option<Duration>,
     sizes: Sizes,
 }
 
@@ -44,19 +45,19 @@ macro_rules! fmt_size {
     }};
 }
 
-impl<'a, 'b, 'c> Output<'a, 'b, 'c> {
+impl<'a, 'b> Output<'a, 'b> {
     pub fn new(
         args: &'a Args,
-        qname: &'b str,
-        msg: &'c [u8],
-        ts: SystemTime,
-        elapsed: Duration,
+        msg: &'b [u8],
+        ns: Option<SocketAddr>,
+        ts: Option<SystemTime>,
+        elapsed: Option<Duration>,
     ) -> Result<Self> {
         let sizes = Self::find_sizes(msg)?;
         Ok(Self {
             args,
-            qname,
             msg,
+            ns,
             ts,
             elapsed,
             sizes,
@@ -233,18 +234,23 @@ impl<'a, 'b, 'c> Output<'a, 'b, 'c> {
 
     fn print_header(&self) {
         println!(
-            "; <<>> ch4 {} <<>> {} {}",
+            "; <<>> ch4 {} <<>> {}",
             env!("CH4_VERSION"),
-            self.args.qtype(),
-            self.qname,
+            self.args.cmd_line()
         );
     }
 
     fn print_footer(&self) {
-        let datetime: DateTime<Local> = DateTime::from(self.ts);
-        println!(";; Query time: {:?}", self.elapsed);
-        println!(";; SERVER: {}", self.args.config.nameserver());
-        println!(";; WHEN: {}", datetime.to_rfc2822());
+        if let Some(elapsed) = self.elapsed {
+            println!(";; Query time: {:?}", elapsed);
+        }
+        if let Some(ns) = self.ns {
+            println!(";; SERVER: {}", ns);
+        }
+        if let Some(ts) = self.ts {
+            let datetime: DateTime<Local> = DateTime::from(ts);
+            println!(";; WHEN: {}", datetime.to_rfc2822());
+        }
         println!(";; MSG SIZE rcvd: {}", self.msg.len());
     }
 }
